# blueplate
*a blueprint for sensible command line tools*

No one likes writing boilerplate. Let Blueplate take care of the headaches and give you a good starting point.

[![License](https://img.shields.io/pypi/l/blueplate)](https://pypi.org/project/blueplate/)

[![Github license](https://img.shields.io/github/license/lawnmowerlatte/blueplate.svg "Github license")](https://github.com/lawnmowerlatte/blueplate/blob/master/LICENSE)

[![Open issues](https://img.shields.io/github/issues/lawnmowerlatte/blueplate.svg "Open issues")](https://github.com/lawnmowerlatte/blueplate/issues)
[![Closed issues](https://img.shields.io/github/issues-closed/lawnmowerlatte/blueplate.svg "Closed issues")](https://github.com/lawnmowerlatte/blueplate/issues?utf8=✓&q=is%3Aissue+is%3Aclosed)

[![Open Pull Requests](https://img.shields.io/github/issues-pr/lawnmowerlatte/blueplate.svg "Open Pull Requests")](https://github.com/lawnmowerlatte/blueplate/pulls)
[![Closed Pull Requests](https://img.shields.io/github/issues-pr-closed/lawnmowerlatte/blueplate.svg "Closed Pull Requests")](https://github.com/lawnmowerlatte/blueplate/pulls?utf8=✓&q=is%3Apr+is%3Aclosed)